==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractSpecialInvokeExpr.h <==
// public abstract class soot.jimple.internal.AbstractSpecialInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceInvokeExpr

#include "soot/jimple/internal/AbstractInstanceInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractSpecialInvokeExpr_H_
#define _JC_soot_jimple_internal_AbstractSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$_init$a6c042a1aa3df261(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object_array *);

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *);
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern jint _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$equivHashCode$a61e38ee84d179c1(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *);
extern jboolean _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$equivTo$4576338963d2dec1(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *);
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$equivHashCode$a61e38ee84d179c1;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$equivTo$4576338963d2dec1;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	jint	(*equivHashCode$a61e38ee84d179c1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *);
	jboolean	(*equivTo$4576338963d2dec1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs {
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object {
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractSpecialInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractSpecialInvokeExpr.h <==
// public abstract class soot.jimple.internal.AbstractSpecialInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceInvokeExpr

#include "soot/jimple/internal/AbstractInstanceInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractSpecialInvokeExpr_H_
#define _JC_soot_jimple_internal_AbstractSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$_init$a6c042a1aa3df261(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$equivHashCode$a61e38ee84d179c1(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$equivTo$4576338963d2dec1(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$equivHashCode$a61e38ee84d179c1;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$equivTo$4576338963d2dec1;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jint	(*equivHashCode$a61e38ee84d179c1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	jboolean	(*equivTo$4576338963d2dec1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs {
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$object {
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vtype _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractSpecialInvokeExpr_H_ */
